@@ -128,6 +128,9 @@ class MainWindow(Qw.QMainWindow, Ui_MainWindow):
         logger.info("Closing window.")
         self.abort_translation_worker.emit()
         if self.threadpool.activeThreadCount():
+            self.statusbar.showMessage("Waiting for threads to finish...")
+            # Process Qt events so that the message shows up.
+            Qc.QCoreApplication.processEvents()
             self.threadpool.waitForDone()
 
         nuke_epub_cache()
@@ -316,7 +319,6 @@ class MainWindow(Qw.QMainWindow, Ui_MainWindow):
         if response == Qw.QDialog.Accepted:
             # Adopt changes from the dialog.
             self.config.api_key = api_conf_dialog.lineEdit_api_key.text()
-            self.config.is_pro_version = api_conf_dialog.comboBox_api_type.currentIndex() == 1
             self.config.save()
             self.load_config_to_ui()
 
@@ -476,7 +478,7 @@ class MainWindow(Qw.QMainWindow, Ui_MainWindow):
             warning_msg = (
                 f"You are about to translate {hp.format_char_count(total_chars)} "
                 f"{hp.f_plural(total_chars, 'character')}, "
-                f"which exceeds your character limit of {hp.format_char_count(allowed_chars)}.\nProceed anyway?"
+                f"which exceeds your remaining character limit of {hp.format_char_count(allowed_chars)}.\nProceed anyway?"
             )
         # Ask the user if he wants to proceed, just in case.
         logger.info(f"Character limit warning: {warning_msg}")
@@ -494,7 +496,7 @@ class MainWindow(Qw.QMainWindow, Ui_MainWindow):
         :param exit_code: The exit code of the translation.
         """
 
-        logger.info("Translation finished.")
+        logger.info(f"Translation finished with exit code {exit_code}")
         self.text_output_changed.emit()
 
         if exit_code == ai.State.DONE:
@@ -510,6 +512,12 @@ class MainWindow(Qw.QMainWindow, Ui_MainWindow):
                 for file_id in self.file_table.files:
                     self.write_output_file(file_id)
 
+        elif exit_code == ai.State.QUOTA_EXCEEDED:
+            self.statusbar.showMessage("API quota exceeded.")
+            show_warning(self, "API Quota Exceeded", "The DeepL API quota has been exceeded.\nDumping output files.")
+            for file_id in self.file_table.files:
+                self.write_output_file(file_id)
+
         self.translation_worker_finished()
 
     def translation_worker_progress(self, key: str, message: str, processed_chars: int | None, total_chars: int | None):
@@ -559,12 +567,27 @@ class MainWindow(Qw.QMainWindow, Ui_MainWindow):
         """
 
         file = self.file_table.files[file_id]
-        if isinstance(file, st.TextFile):
-            self.write_output_text_file(file_id)
-        elif isinstance(file, st.EpubFile):
-            self.write_output_epub_file(file_id)
-        else:
-            raise TypeError(f"Unknown file type: {file}")
+        try:
+            if isinstance(file, st.TextFile):
+                self.write_output_text_file(file_id)
+            elif isinstance(file, st.EpubFile):
+                self.write_output_epub_file(file_id)
+            else:
+                raise TypeError(f"Unknown file type: {file}")
+
+        except OSError as e:
+            path_out = make_output_filename(file, self.config)
+            logger.error(f"Failed to write translation to {path_out}.\n{e}\n\n")
+            show_warning(
+                self,
+                "Output Error",
+                f"Failed to write translation to {path_out}.\n\n{e}\n\n"
+                f"Please make sure you have write permissions to the output directory.\n"
+                f"To save the translation in another location without needing to re-translate, "
+                f'select your file, then click the "preview" button.\n'
+                f'There, select the translated version and press the "Save Preview to File" button.',
+            )
+            self.file_table.show_file_progress(file_id, "Could not write output!")
 
     def write_output_text_file(self, file_id: str):
         """
@@ -589,21 +612,16 @@ class MainWindow(Qw.QMainWindow, Ui_MainWindow):
             self.file_table.show_file_progress(file_id, "Not translated.")
             return
         else:
-            try:
-                # Ensure the output directory exists.
-                path_out.parent.mkdir(parents=True, exist_ok=True)
+            # Ensure the output directory exists.
+            path_out.parent.mkdir(parents=True, exist_ok=True)
 
-                with open(path_out, "w", encoding="utf-8") as f:
-                    f.write(text_out)
-                    logger.info(f"Wrote translation to {path_out}")
-                    if file.translation_incomplete():
-                        self.file_table.show_file_progress(file_id, "Incomplete output written.")
-                    else:
-                        self.file_table.show_file_progress(file_id, "Translation written.")
-            except OSError as e:
-                logger.error(f"Failed to write translation to {path_out}.\n{e}")
-                show_warning(self, "Output Error", f"Failed to write translation to {path_out}.")
-                self.file_table.show_file_progress(file_id, "Could not write output!")
+            with open(path_out, "w", encoding="utf-8") as f:
+                f.write(text_out)
+                logger.info(f"Wrote translation to {path_out}")
+                if file.translation_incomplete():
+                    self.file_table.show_file_progress(file_id, "Incomplete output written.")
+                else:
+                    self.file_table.show_file_progress(file_id, "Translation written.")
 
     def write_output_epub_file(self, file_id: str):
         """
@@ -637,17 +655,23 @@ class MainWindow(Qw.QMainWindow, Ui_MainWindow):
     def set_up_statusbar(self):
         """
         Add a label to show the current char total and time estimate.
+        Add a flat button to the statusbar to offer opening the config file.
         Add a flat button to the statusbar to offer opening the log file.
         """
         self.statusbar.setSizeGripEnabled(False)
+        self.statusbar.setContentsMargins(0, 0, 6, 0)
 
         self.label_stats = Qw.QLabel("")
         self.statusbar.addPermanentWidget(self.label_stats)
 
+        button_config = Qw.QPushButton("Open Config")
+        button_config.clicked.connect(partial(hp.open_file, cfg.config_path()))
+        button_config.setFlat(True)
+        self.statusbar.addPermanentWidget(button_config)
+
         button_log = Qw.QPushButton("Open Log")
         button_log.clicked.connect(partial(hp.open_file, cfg.log_path()))
         button_log.setFlat(True)
-        self.statusbar.setContentsMargins(0, 0, 6, 0)
         self.statusbar.addPermanentWidget(button_log)
 
     """
@@ -778,7 +802,7 @@ class MainWindow(Qw.QMainWindow, Ui_MainWindow):
         Update the translation status label.
         """
         if char_total == 0:
-            logger.error("Total character count is 0. Nothing to do.")
+            logger.info("Total character count is 0. Nothing to do.")
             return
         char_text = hp.format_char_count(processed_chars) + " / " + hp.format_char_count(char_total)
         time_total = ceil(self.config.avg_time_per_mille * (char_total - processed_chars) / 1000)
